@@ -12,7 +12,7 @@ class RadioKapitalBaseIE(InfoExtractor):
             video_id, note=note)
 
     def _parse_episode(self, data):
-        release = '%s%s%s' % (data['published'][6:11], data['published'][3:6], data['published'][:3])
+        release = '{}{}{}'.format(data['published'][6:11], data['published'][3:6], data['published'][:3])
         return {
             '_type': 'url_transparent',
             'url': data['mixcloud_url'],
@@ -46,7 +46,7 @@ class RadioKapitalIE(RadioKapitalBaseIE):
     def _real_extract(self, url):
         video_id = self._match_id(url)
 
-        episode = self._call_api('episodes/%s' % video_id, video_id)
+        episode = self._call_api(f'episodes/{video_id}', video_id)
         return self._parse_episode(episode)
 
 
