@@ -12,6 +12,7 @@ import urllib.response
 from collections.abc import Iterable, Mapping
 from email.message import Message
 from http import HTTPStatus
+from types import NoneType
 
 from ._helper import make_ssl_context, wrap_request_errors
 from .exceptions import (
@@ -20,7 +21,6 @@ from .exceptions import (
     TransportError,
     UnsupportedRequest,
 )
-from ..compat.types import NoneType
 from ..cookies import YoutubeDLCookieJar
 from ..utils import (
     bug_reports_message,
@@ -505,6 +505,7 @@ class Request:
 
 
 HEADRequest = functools.partial(Request, method='HEAD')
+PATCHRequest = functools.partial(Request, method='PATCH')
 PUTRequest = functools.partial(Request, method='PUT')
 
 
